# af_worklist_manager
No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 6.0.0
- Package version: 6.0.4
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import af_worklist_manager 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import af_worklist_manager
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import af_worklist_manager
from af_worklist_manager.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = af_worklist_manager.AristaFlowServiceApi(af_worklist_manager.ApiClient(configuration))

try:
    api_response = api_instance.get_release()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AristaFlowServiceApi->get_release: %s\n" % e)

# create an instance of the API class
api_instance = af_worklist_manager.AristaFlowServiceApi(af_worklist_manager.ApiClient(configuration))

try:
    api_response = api_instance.get_service_instance_name()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AristaFlowServiceApi->get_service_instance_name: %s\n" % e)

# create an instance of the API class
api_instance = af_worklist_manager.AristaFlowServiceApi(af_worklist_manager.ApiClient(configuration))

try:
    api_response = api_instance.get_uris()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AristaFlowServiceApi->get_uris: %s\n" % e)

# create an instance of the API class
api_instance = af_worklist_manager.AristaFlowServiceApi(af_worklist_manager.ApiClient(configuration))

try:
    api_response = api_instance.ping()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AristaFlowServiceApi->ping: %s\n" % e)

# create an instance of the API class
api_instance = af_worklist_manager.AristaFlowServiceApi(af_worklist_manager.ApiClient(configuration))

try:
    api_instance.register_sse()
except ApiException as e:
    print("Exception when calling AristaFlowServiceApi->register_sse: %s\n" % e)

# create an instance of the API class
api_instance = af_worklist_manager.AristaFlowServiceApi(af_worklist_manager.ApiClient(configuration))
sse_id = '38400000-8cf0-11bd-b23e-10b96e4ef00d' # str | 

try:
    api_response = api_instance.unregister_sse(sse_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AristaFlowServiceApi->unregister_sse: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to */*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AristaFlowServiceApi* | [**get_release**](docs/AristaFlowServiceApi.md#get_release) | **GET** /release | 
*AristaFlowServiceApi* | [**get_service_instance_name**](docs/AristaFlowServiceApi.md#get_service_instance_name) | **GET** /service-instance-name | 
*AristaFlowServiceApi* | [**get_uris**](docs/AristaFlowServiceApi.md#get_uris) | **GET** /uris | 
*AristaFlowServiceApi* | [**ping**](docs/AristaFlowServiceApi.md#ping) | **GET** /start-time | 
*AristaFlowServiceApi* | [**register_sse**](docs/AristaFlowServiceApi.md#register_sse) | **GET** /sse | 
*AristaFlowServiceApi* | [**unregister_sse**](docs/AristaFlowServiceApi.md#unregister_sse) | **DELETE** /sse/{sseId} | 
*DelRecRemoteIteratorApi* | [**del_rec_close**](docs/DelRecRemoteIteratorApi.md#del_rec_close) | **DELETE** /DelegationManager/DelegationRecipientIterator/{iteratorId} | 
*DelRecRemoteIteratorApi* | [**del_rec_get_next**](docs/DelRecRemoteIteratorApi.md#del_rec_get_next) | **GET** /DelegationManager/DelegationRecipientIterator/{iteratorId}/next | 
*DelRecRemoteIteratorApi* | [**del_rec_get_previous**](docs/DelRecRemoteIteratorApi.md#del_rec_get_previous) | **GET** /DelegationManager/DelegationRecipientIterator/{iteratorId}/previous | 
*DelRecRemoteIteratorApi* | [**del_rec_keep_alive**](docs/DelRecRemoteIteratorApi.md#del_rec_keep_alive) | **GET** /DelegationManager/DelegationRecipientIterator/{iteratorId}/remaining-alive-time | 
*DelegationManagerApi* | [**delegate_back**](docs/DelegationManagerApi.md#delegate_back) | **POST** /DelegationManager/{itemId}/back-delegation | 
*DelegationManagerApi* | [**delegate_work_item**](docs/DelegationManagerApi.md#delegate_work_item) | **POST** /DelegationManager/{itemId}/delegation | 
*DelegationManagerApi* | [**get_delegation_recipients**](docs/DelegationManagerApi.md#get_delegation_recipients) | **GET** /DelegationManager/DelegationRecipientIterator/delegation-recipient/{itemId} | 
*IncAdminWorklistsApi* | [**inc_admin_wl_close**](docs/IncAdminWorklistsApi.md#inc_admin_wl_close) | **DELETE** /Administration/IncrementalWorklist/{incWlId} | 
*IncAdminWorklistsApi* | [**inc_admin_wl_get_next**](docs/IncAdminWorklistsApi.md#inc_admin_wl_get_next) | **GET** /Administration/IncrementalWorklist/{incWlId}/next | 
*IncAdminWorklistsApi* | [**inc_admin_wl_get_previous**](docs/IncAdminWorklistsApi.md#inc_admin_wl_get_previous) | **GET** /Administration/IncrementalWorklist/{incWlId}/previous | 
*IncClientWorklistsApi* | [**inc_client_wl_close**](docs/IncClientWorklistsApi.md#inc_client_wl_close) | **DELETE** /WorklistUpdateManager/IncrementalWorklist/{incWlId} | 
*IncClientWorklistsApi* | [**inc_client_wl_get_next**](docs/IncClientWorklistsApi.md#inc_client_wl_get_next) | **GET** /WorklistUpdateManager/IncrementalWorklist/{incWlId}/next | 
*IncClientWorklistsApi* | [**inc_client_wl_get_previous**](docs/IncClientWorklistsApi.md#inc_client_wl_get_previous) | **GET** /WorklistUpdateManager/IncrementalWorklist/{incWlId}/previous | 
*IncWorklistUpdateApi* | [**inc_wl_updt_close**](docs/IncWorklistUpdateApi.md#inc_wl_updt_close) | **DELETE** /WorklistUpdateManager/IncrementalWorklistUpdate/{incUpdId} | 
*IncWorklistUpdateApi* | [**inc_wl_updt_get_next**](docs/IncWorklistUpdateApi.md#inc_wl_updt_get_next) | **GET** /WorklistUpdateManager/IncrementalWorklistUpdate/{incUpdId}/next | 
*IncWorklistUpdateApi* | [**inc_wl_updt_get_previous**](docs/IncWorklistUpdateApi.md#inc_wl_updt_get_previous) | **GET** /WorklistUpdateManager/IncrementalWorklistUpdate/{incUpdId}/previous | 
*PossAbsRemoteIteratorApi* | [**poss_abs_close**](docs/PossAbsRemoteIteratorApi.md#poss_abs_close) | **DELETE** /WorklistUpdateManager/PossibleAbsenteeIterator/{iteratorId} | 
*PossAbsRemoteIteratorApi* | [**poss_abs_get_next**](docs/PossAbsRemoteIteratorApi.md#poss_abs_get_next) | **GET** /WorklistUpdateManager/PossibleAbsenteeIterator/{iteratorId}/next | 
*PossAbsRemoteIteratorApi* | [**poss_abs_get_previous**](docs/PossAbsRemoteIteratorApi.md#poss_abs_get_previous) | **GET** /WorklistUpdateManager/PossibleAbsenteeIterator/{iteratorId}/previous | 
*PossAbsRemoteIteratorApi* | [**poss_abs_keep_alive**](docs/PossAbsRemoteIteratorApi.md#poss_abs_keep_alive) | **GET** /WorklistUpdateManager/PossibleAbsenteeIterator/{iteratorId}/remaining-alive-time | 
*WorklistAdministrationApi* | [**get_global_worklist**](docs/WorklistAdministrationApi.md#get_global_worklist) | **PUT** /Administration/IncrementalWorklist/global-worklist | 
*WorklistAdministrationApi* | [**get_global_worklist_all**](docs/WorklistAdministrationApi.md#get_global_worklist_all) | **GET** /Administration/IncrementalWorklist/global-worklist | 
*WorklistAdministrationApi* | [**get_internal_worklist**](docs/WorklistAdministrationApi.md#get_internal_worklist) | **PUT** /Administration/IncrementalWorklist/worklist/{worklistId} | 
*WorklistAdministrationApi* | [**get_internal_worklist_all**](docs/WorklistAdministrationApi.md#get_internal_worklist_all) | **GET** /Administration/IncrementalWorklist/worklist/{worklistId} | 
*WorklistAdministrationApi* | [**get_worklist_id**](docs/WorklistAdministrationApi.md#get_worklist_id) | **PUT** /Administration/worklist-id | 
*WorklistAdministrationApi* | [**get_worklist_item**](docs/WorklistAdministrationApi.md#get_worklist_item) | **PUT** /Administration/worklist-item | 
*WorklistAdministrationApi* | [**get_worklists_containing**](docs/WorklistAdministrationApi.md#get_worklists_containing) | **PUT** /Administration/containing-worklists | 
*WorklistAdministrationApi* | [**is_on_worklist**](docs/WorklistAdministrationApi.md#is_on_worklist) | **PUT** /Administration/on-worklist | 
*WorklistAdministrationApi* | [**reassess**](docs/WorklistAdministrationApi.md#reassess) | **PUT** /Administration/reassessment | 
*WorklistAdministrationApi* | [**reconnect_to_execution_manager**](docs/WorklistAdministrationApi.md#reconnect_to_execution_manager) | **GET** /Administration/executionmanager-reconnect | 
*WorklistAdministrationApi* | [**redistribute_items**](docs/WorklistAdministrationApi.md#redistribute_items) | **PUT** /Administration/redistribution/items | 
*WorklistAdministrationApi* | [**redistribute_items_reg_exp**](docs/WorklistAdministrationApi.md#redistribute_items_reg_exp) | **PUT** /Administration/redistribution/regexp | 
*WorklistAdministrationApi* | [**redistribute_items_sar**](docs/WorklistAdministrationApi.md#redistribute_items_sar) | **PUT** /Administration/redistribution/sar | 
*WorklistAdministrationApi* | [**remove_internal_worklist**](docs/WorklistAdministrationApi.md#remove_internal_worklist) | **DELETE** /Administration/{worklistId} | 
*WorklistManagerApi* | [**get_org_model_manager**](docs/WorklistManagerApi.md#get_org_model_manager) | **GET** /org-model-manager | 
*WorklistManagerApi* | [**get_worklist_configuration**](docs/WorklistManagerApi.md#get_worklist_configuration) | **GET** /{worklistId}/configuration | 
*WorklistManagerApi* | [**logoff**](docs/WorklistManagerApi.md#logoff) | **GET** /logoff | 
*WorklistManagerApi* | [**logon**](docs/WorklistManagerApi.md#logon) | **GET** /logon | 
*WorklistManagerApi* | [**set_worklist_configuration**](docs/WorklistManagerApi.md#set_worklist_configuration) | **PUT** /{worklistId}/configuration | 
*WorklistUpdateManagerApi* | [**create_client_worklist**](docs/WorklistUpdateManagerApi.md#create_client_worklist) | **PUT** /WorklistUpdateManager/IncrementalWorklist/client-worklist/{worklistId} | 
*WorklistUpdateManagerApi* | [**create_default_client_worklist**](docs/WorklistUpdateManagerApi.md#create_default_client_worklist) | **GET** /WorklistUpdateManager/IncrementalWorklist/client-worklist/{worklistId} | 
*WorklistUpdateManagerApi* | [**drop_absence**](docs/WorklistUpdateManagerApi.md#drop_absence) | **POST** /WorklistUpdateManager/absence | 
*WorklistUpdateManagerApi* | [**get_absence_information**](docs/WorklistUpdateManagerApi.md#get_absence_information) | **PUT** /WorklistUpdateManager/presence | 
*WorklistUpdateManagerApi* | [**get_all_worklist_updates**](docs/WorklistUpdateManagerApi.md#get_all_worklist_updates) | **GET** /WorklistUpdateManager/IncrementalWorklistUpdate/update/{worklistId} | 
*WorklistUpdateManagerApi* | [**get_attached_data_context**](docs/WorklistUpdateManagerApi.md#get_attached_data_context) | **GET** /WorklistUpdateManager/{itemId}/attached-data-context | 
*WorklistUpdateManagerApi* | [**get_attached_resources**](docs/WorklistUpdateManagerApi.md#get_attached_resources) | **GET** /WorklistUpdateManager/{itemId}/attached-resources | 
*WorklistUpdateManagerApi* | [**get_mail_notification_information**](docs/WorklistUpdateManagerApi.md#get_mail_notification_information) | **PUT** /WorklistUpdateManager/mail-notification | 
*WorklistUpdateManagerApi* | [**get_possible_absentees**](docs/WorklistUpdateManagerApi.md#get_possible_absentees) | **GET** /WorklistUpdateManager/PossibleAbsenteeIterator/possible-absentee | 
*WorklistUpdateManagerApi* | [**get_worklist_updates**](docs/WorklistUpdateManagerApi.md#get_worklist_updates) | **PUT** /WorklistUpdateManager/IncrementalWorklistUpdate/update/{worklistId} | 
*WorklistUpdateManagerApi* | [**is_registered_for_updates**](docs/WorklistUpdateManagerApi.md#is_registered_for_updates) | **GET** /WorklistUpdateManager/client-worklist-subscription/{worklistId}/{clientWorklistId} | 
*WorklistUpdateManagerApi* | [**logon_and_create_client_worklist**](docs/WorklistUpdateManagerApi.md#logon_and_create_client_worklist) | **PUT** /WorklistUpdateManager/IncrementalWorklist/client-worklist-logon | 
*WorklistUpdateManagerApi* | [**logon_and_create_default_client_worklist**](docs/WorklistUpdateManagerApi.md#logon_and_create_default_client_worklist) | **GET** /WorklistUpdateManager/IncrementalWorklist/client-worklist-logon | 
*WorklistUpdateManagerApi* | [**register_client_worklist_callback**](docs/WorklistUpdateManagerApi.md#register_client_worklist_callback) | **POST** /WorklistUpdateManager/client-worklist-subscription/callback | 
*WorklistUpdateManagerApi* | [**register_client_worklist_sse**](docs/WorklistUpdateManagerApi.md#register_client_worklist_sse) | **POST** /WorklistUpdateManager/client-worklist-subscription/sse | 
*WorklistUpdateManagerApi* | [**reject_worklist_item**](docs/WorklistUpdateManagerApi.md#reject_worklist_item) | **GET** /WorklistUpdateManager/{worklistId}/{itemId}/rejection | 
*WorklistUpdateManagerApi* | [**set_absent**](docs/WorklistUpdateManagerApi.md#set_absent) | **PUT** /WorklistUpdateManager/absence | 
*WorklistUpdateManagerApi* | [**set_mail_notification**](docs/WorklistUpdateManagerApi.md#set_mail_notification) | **POST** /WorklistUpdateManager/mail-notification | 
*WorklistUpdateManagerApi* | [**set_present**](docs/WorklistUpdateManagerApi.md#set_present) | **POST** /WorklistUpdateManager/presence | 
*WorklistUpdateManagerApi* | [**unregister_client_worklist_callback**](docs/WorklistUpdateManagerApi.md#unregister_client_worklist_callback) | **DELETE** /WorklistUpdateManager/client-worklist-unsubscription/{worklistId}/{clientWorklistId} | 
*WorklistUpdateManagerApi* | [**update_individual_settings**](docs/WorklistUpdateManagerApi.md#update_individual_settings) | **PUT** /WorklistUpdateManager/individual-settings | 
*DefaultApi* | [**header_data**](docs/DefaultApi.md#header_data) | **PUT** /header-data | 

## Documentation For Models

 - [AbortServiceException](docs/AbortServiceException.md)
 - [AbortTransactionException](docs/AbortTransactionException.md)
 - [AbsenceData](docs/AbsenceData.md)
 - [AbsenceInformation](docs/AbsenceInformation.md)
 - [AccessedProcessModelParameter](docs/AccessedProcessModelParameter.md)
 - [ActivityAgent](docs/ActivityAgent.md)
 - [ActivityConfiguration](docs/ActivityConfiguration.md)
 - [ActivityReference](docs/ActivityReference.md)
 - [ActivityReferenceFilter](docs/ActivityReferenceFilter.md)
 - [ActivityReferenceSelection](docs/ActivityReferenceSelection.md)
 - [ActivityReferenceTypeFilter](docs/ActivityReferenceTypeFilter.md)
 - [ActivityReferenceTypeIn](docs/ActivityReferenceTypeIn.md)
 - [ActivityReferenceTypeNotIn](docs/ActivityReferenceTypeNotIn.md)
 - [ActivityReferenceTypeNullEq](docs/ActivityReferenceTypeNullEq.md)
 - [ActivityReferenceTypeNullNe](docs/ActivityReferenceTypeNullNe.md)
 - [AdeptDataTypeFilter](docs/AdeptDataTypeFilter.md)
 - [AdeptDataTypeIn](docs/AdeptDataTypeIn.md)
 - [AdeptDataTypeNotIn](docs/AdeptDataTypeNotIn.md)
 - [AdministrativeWorklistItem](docs/AdministrativeWorklistItem.md)
 - [AdministrativeWorklistItemFilter](docs/AdministrativeWorklistItemFilter.md)
 - [AdministrativeWorklistItemSelection](docs/AdministrativeWorklistItemSelection.md)
 - [AfActivityReference](docs/AfActivityReference.md)
 - [AfActivityReferenceSelection](docs/AfActivityReferenceSelection.md)
 - [AfConfiguration](docs/AfConfiguration.md)
 - [AfEbpReference](docs/AfEbpReference.md)
 - [AfEbpReferenceSelection](docs/AfEbpReferenceSelection.md)
 - [AfInstanceReference](docs/AfInstanceReference.md)
 - [AfInstanceReferenceSelection](docs/AfInstanceReferenceSelection.md)
 - [AgentUnknownException](docs/AgentUnknownException.md)
 - [AllDelFilter](docs/AllDelFilter.md)
 - [AllQaFilter](docs/AllQaFilter.md)
 - [AllSpFilter](docs/AllSpFilter.md)
 - [AllUriFilter](docs/AllUriFilter.md)
 - [AllUuidFilter](docs/AllUuidFilter.md)
 - [AndActRefFilter](docs/AndActRefFilter.md)
 - [AndAwiFilter](docs/AndAwiFilter.md)
 - [AndBooleanFilter](docs/AndBooleanFilter.md)
 - [AndCollDelFilter](docs/AndCollDelFilter.md)
 - [AndCollQaFilter](docs/AndCollQaFilter.md)
 - [AndCollSpFilter](docs/AndCollSpFilter.md)
 - [AndCollUriFilter](docs/AndCollUriFilter.md)
 - [AndCollUuidFilter](docs/AndCollUuidFilter.md)
 - [AndCwiFilter](docs/AndCwiFilter.md)
 - [AndDelFilter](docs/AndDelFilter.md)
 - [AndDoubleFilter](docs/AndDoubleFilter.md)
 - [AndEcpFilter](docs/AndEcpFilter.md)
 - [AndEnqFilter](docs/AndEnqFilter.md)
 - [AndIdcFilter](docs/AndIdcFilter.md)
 - [AndInstantFilter](docs/AndInstantFilter.md)
 - [AndIntegerFilter](docs/AndIntegerFilter.md)
 - [AndLongFilter](docs/AndLongFilter.md)
 - [AndQaFilter](docs/AndQaFilter.md)
 - [AndSpFilter](docs/AndSpFilter.md)
 - [AndStringFilter](docs/AndStringFilter.md)
 - [AndUasFilter](docs/AndUasFilter.md)
 - [AndUriFilter](docs/AndUriFilter.md)
 - [AndUuidFilter](docs/AndUuidFilter.md)
 - [Assessment](docs/Assessment.md)
 - [Attribute](docs/Attribute.md)
 - [AttributeList](docs/AttributeList.md)
 - [AuthenticationException](docs/AuthenticationException.md)
 - [BooleanEq](docs/BooleanEq.md)
 - [BooleanFilter](docs/BooleanFilter.md)
 - [BooleanNe](docs/BooleanNe.md)
 - [ClientWorklistCallbackData](docs/ClientWorklistCallbackData.md)
 - [ClientWorklistItem](docs/ClientWorklistItem.md)
 - [ClientWorklistItemFilter](docs/ClientWorklistItemFilter.md)
 - [ClientWorklistItemSelection](docs/ClientWorklistItemSelection.md)
 - [ClientWorklistItemUpdate](docs/ClientWorklistItemUpdate.md)
 - [ClientWorklistRestCallbackData](docs/ClientWorklistRestCallbackData.md)
 - [ClientWorklistSseCallbackData](docs/ClientWorklistSseCallbackData.md)
 - [CollectionDelFilter](docs/CollectionDelFilter.md)
 - [CollectionDelNullEq](docs/CollectionDelNullEq.md)
 - [CollectionDelNullNe](docs/CollectionDelNullNe.md)
 - [CollectionDelSizeFilter](docs/CollectionDelSizeFilter.md)
 - [CollectionQaFilter](docs/CollectionQaFilter.md)
 - [CollectionQaNullEq](docs/CollectionQaNullEq.md)
 - [CollectionQaNullNe](docs/CollectionQaNullNe.md)
 - [CollectionQaSizeFilter](docs/CollectionQaSizeFilter.md)
 - [CollectionSpFilter](docs/CollectionSpFilter.md)
 - [CollectionSpNullEq](docs/CollectionSpNullEq.md)
 - [CollectionSpNullNe](docs/CollectionSpNullNe.md)
 - [CollectionSpSizeFilter](docs/CollectionSpSizeFilter.md)
 - [CollectionUriFilter](docs/CollectionUriFilter.md)
 - [CollectionUriNullEq](docs/CollectionUriNullEq.md)
 - [CollectionUriNullNe](docs/CollectionUriNullNe.md)
 - [CollectionUriSizeFilter](docs/CollectionUriSizeFilter.md)
 - [CollectionUuidFilter](docs/CollectionUuidFilter.md)
 - [CollectionUuidNullEq](docs/CollectionUuidNullEq.md)
 - [CollectionUuidNullNe](docs/CollectionUuidNullNe.md)
 - [CollectionUuidSizeFilter](docs/CollectionUuidSizeFilter.md)
 - [ConfigurationException](docs/ConfigurationException.md)
 - [DataConsistencyException](docs/DataConsistencyException.md)
 - [DataContext](docs/DataContext.md)
 - [DataSourceException](docs/DataSourceException.md)
 - [Delegation](docs/Delegation.md)
 - [DelegationFilter](docs/DelegationFilter.md)
 - [DelegationNullEq](docs/DelegationNullEq.md)
 - [DelegationNullNe](docs/DelegationNullNe.md)
 - [DelegationSelection](docs/DelegationSelection.md)
 - [DelgRecWithComment](docs/DelgRecWithComment.md)
 - [DirectTemplate](docs/DirectTemplate.md)
 - [DoubleEq](docs/DoubleEq.md)
 - [DoubleFilter](docs/DoubleFilter.md)
 - [DoubleGe](docs/DoubleGe.md)
 - [DoubleGt](docs/DoubleGt.md)
 - [DoubleLe](docs/DoubleLe.md)
 - [DoubleLt](docs/DoubleLt.md)
 - [DoubleNe](docs/DoubleNe.md)
 - [DummyParent](docs/DummyParent.md)
 - [EbpInstanceReference](docs/EbpInstanceReference.md)
 - [EbpTypeFilter](docs/EbpTypeFilter.md)
 - [EbpTypeIn](docs/EbpTypeIn.md)
 - [EbpTypeNotIn](docs/EbpTypeNotIn.md)
 - [Enquiry](docs/Enquiry.md)
 - [EnquiryFilter](docs/EnquiryFilter.md)
 - [EnquiryNullEq](docs/EnquiryNullEq.md)
 - [EnquiryNullNe](docs/EnquiryNullNe.md)
 - [EnquirySelection](docs/EnquirySelection.md)
 - [ExecutionControlProperties](docs/ExecutionControlProperties.md)
 - [ExecutionControlPropertiesFilter](docs/ExecutionControlPropertiesFilter.md)
 - [ExecutionControlPropertiesSelection](docs/ExecutionControlPropertiesSelection.md)
 - [ExistsDelFilter](docs/ExistsDelFilter.md)
 - [ExistsQaFilter](docs/ExistsQaFilter.md)
 - [ExistsSpFilter](docs/ExistsSpFilter.md)
 - [ExistsUriFilter](docs/ExistsUriFilter.md)
 - [ExistsUuidFilter](docs/ExistsUuidFilter.md)
 - [FlatAttributeSelection](docs/FlatAttributeSelection.md)
 - [FlatDoubleFilter](docs/FlatDoubleFilter.md)
 - [FlatInstantFilter](docs/FlatInstantFilter.md)
 - [FlatLongFilter](docs/FlatLongFilter.md)
 - [FlatStringFilter](docs/FlatStringFilter.md)
 - [GroupReference](docs/GroupReference.md)
 - [GroupReferenceSelection](docs/GroupReferenceSelection.md)
 - [IdentifiedUdtValue](docs/IdentifiedUdtValue.md)
 - [IlmException](docs/IlmException.md)
 - [IlmExceptionCause](docs/IlmExceptionCause.md)
 - [IlmExceptionCauseStackTrace](docs/IlmExceptionCauseStackTrace.md)
 - [IlmExceptionSuppressed](docs/IlmExceptionSuppressed.md)
 - [IlmStackTraceElement](docs/IlmStackTraceElement.md)
 - [IncAdminWorklistData](docs/IncAdminWorklistData.md)
 - [IncClientWorklistData](docs/IncClientWorklistData.md)
 - [IncWorklistData](docs/IncWorklistData.md)
 - [IncWorklistUpdateData](docs/IncWorklistUpdateData.md)
 - [IncompatibleGuiContextException](docs/IncompatibleGuiContextException.md)
 - [InitialIncAdminWorklistData](docs/InitialIncAdminWorklistData.md)
 - [InitialIncClientWorklistData](docs/InitialIncClientWorklistData.md)
 - [InitialIncWorklistUpdateData](docs/InitialIncWorklistUpdateData.md)
 - [InlineResponse400](docs/InlineResponse400.md)
 - [InlineResponse4001](docs/InlineResponse4001.md)
 - [InlineResponse500](docs/InlineResponse500.md)
 - [InlineResponse5001](docs/InlineResponse5001.md)
 - [InputDataContext](docs/InputDataContext.md)
 - [InputDataContextFilter](docs/InputDataContextFilter.md)
 - [InputDataContextNullEq](docs/InputDataContextNullEq.md)
 - [InputDataContextNullNe](docs/InputDataContextNullNe.md)
 - [InputDataContextSelection](docs/InputDataContextSelection.md)
 - [InstantEq](docs/InstantEq.md)
 - [InstantFilter](docs/InstantFilter.md)
 - [InstantGe](docs/InstantGe.md)
 - [InstantGt](docs/InstantGt.md)
 - [InstantLe](docs/InstantLe.md)
 - [InstantLt](docs/InstantLt.md)
 - [InstantNe](docs/InstantNe.md)
 - [IntegerEq](docs/IntegerEq.md)
 - [IntegerFilter](docs/IntegerFilter.md)
 - [IntegerGe](docs/IntegerGe.md)
 - [IntegerGt](docs/IntegerGt.md)
 - [IntegerLe](docs/IntegerLe.md)
 - [IntegerLt](docs/IntegerLt.md)
 - [IntegerNe](docs/IntegerNe.md)
 - [InterruptException](docs/InterruptException.md)
 - [InvalidActivityStateException](docs/InvalidActivityStateException.md)
 - [InvalidDataContainerException](docs/InvalidDataContainerException.md)
 - [InvalidInstanceStateException](docs/InvalidInstanceStateException.md)
 - [InvalidTemplateStateException](docs/InvalidTemplateStateException.md)
 - [InvalidWorklistItemStateException](docs/InvalidWorklistItemStateException.md)
 - [ItemIdBackdelegationBody](docs/ItemIdBackdelegationBody.md)
 - [LockException](docs/LockException.md)
 - [LongEq](docs/LongEq.md)
 - [LongFilter](docs/LongFilter.md)
 - [LongGe](docs/LongGe.md)
 - [LongGt](docs/LongGt.md)
 - [LongLe](docs/LongLe.md)
 - [LongLt](docs/LongLt.md)
 - [LongNe](docs/LongNe.md)
 - [MailNotificationData](docs/MailNotificationData.md)
 - [OrActRefFilter](docs/OrActRefFilter.md)
 - [OrAwiFilter](docs/OrAwiFilter.md)
 - [OrBooleanFilter](docs/OrBooleanFilter.md)
 - [OrCollDelFilter](docs/OrCollDelFilter.md)
 - [OrCollQaFilter](docs/OrCollQaFilter.md)
 - [OrCollSpFilter](docs/OrCollSpFilter.md)
 - [OrCollUriFilter](docs/OrCollUriFilter.md)
 - [OrCollUuidFilter](docs/OrCollUuidFilter.md)
 - [OrCwiFilter](docs/OrCwiFilter.md)
 - [OrDelFilter](docs/OrDelFilter.md)
 - [OrDoubleFilter](docs/OrDoubleFilter.md)
 - [OrEcpFilter](docs/OrEcpFilter.md)
 - [OrEnqFilter](docs/OrEnqFilter.md)
 - [OrIdcFilter](docs/OrIdcFilter.md)
 - [OrInstantFilter](docs/OrInstantFilter.md)
 - [OrIntegerFilter](docs/OrIntegerFilter.md)
 - [OrLongFilter](docs/OrLongFilter.md)
 - [OrQaFilter](docs/OrQaFilter.md)
 - [OrSpFilter](docs/OrSpFilter.md)
 - [OrStringFilter](docs/OrStringFilter.md)
 - [OrUasFilter](docs/OrUasFilter.md)
 - [OrUriFilter](docs/OrUriFilter.md)
 - [OrUuidFilter](docs/OrUuidFilter.md)
 - [OrgModelException](docs/OrgModelException.md)
 - [ParameterException](docs/ParameterException.md)
 - [ParameterMissingException](docs/ParameterMissingException.md)
 - [ParameterTypeException](docs/ParameterTypeException.md)
 - [ParameterValue](docs/ParameterValue.md)
 - [PasswordPolicyException](docs/PasswordPolicyException.md)
 - [PlainTextException](docs/PlainTextException.md)
 - [Poi](docs/Poi.md)
 - [PoiAttribute](docs/PoiAttribute.md)
 - [PolicyResolutionException](docs/PolicyResolutionException.md)
 - [ProcessModelParameter](docs/ProcessModelParameter.md)
 - [ProcessStartRef](docs/ProcessStartRef.md)
 - [ProcessStartRefAttribute](docs/ProcessStartRefAttribute.md)
 - [ProcessTemplateRef](docs/ProcessTemplateRef.md)
 - [ProcessTrigger](docs/ProcessTrigger.md)
 - [QaAssessment](docs/QaAssessment.md)
 - [QaInitialRemoteIteratorData](docs/QaInitialRemoteIteratorData.md)
 - [QaRemoteIteratorData](docs/QaRemoteIteratorData.md)
 - [QualifiedAgent](docs/QualifiedAgent.md)
 - [QualifiedAgentFilter](docs/QualifiedAgentFilter.md)
 - [QualifiedAgentIds](docs/QualifiedAgentIds.md)
 - [QualifiedAgentNullEq](docs/QualifiedAgentNullEq.md)
 - [QualifiedAgentNullNe](docs/QualifiedAgentNullNe.md)
 - [QualifiedAgentSelection](docs/QualifiedAgentSelection.md)
 - [RedistributionRegexpBody](docs/RedistributionRegexpBody.md)
 - [RedistributionSarBody](docs/RedistributionSarBody.md)
 - [ResInstInitialRemoteIteratorData](docs/ResInstInitialRemoteIteratorData.md)
 - [Resource](docs/Resource.md)
 - [ResourceInstance](docs/ResourceInstance.md)
 - [ResourceRefAttribute](docs/ResourceRefAttribute.md)
 - [RichAgent](docs/RichAgent.md)
 - [ScriptEnvironmentException](docs/ScriptEnvironmentException.md)
 - [ScriptEvaluationException](docs/ScriptEvaluationException.md)
 - [ScriptException](docs/ScriptException.md)
 - [Sensor](docs/Sensor.md)
 - [SensorAttribute](docs/SensorAttribute.md)
 - [ServiceInstanceName](docs/ServiceInstanceName.md)
 - [ServiceNotKnownException](docs/ServiceNotKnownException.md)
 - [ServiceRelease](docs/ServiceRelease.md)
 - [Session](docs/Session.md)
 - [SessionToken](docs/SessionToken.md)
 - [SimpleParameter](docs/SimpleParameter.md)
 - [SimpleParameterFilter](docs/SimpleParameterFilter.md)
 - [SimpleParameterSelection](docs/SimpleParameterSelection.md)
 - [SinceRevisionWithFilter](docs/SinceRevisionWithFilter.md)
 - [StringEq](docs/StringEq.md)
 - [StringFilter](docs/StringFilter.md)
 - [StringLike](docs/StringLike.md)
 - [StringNe](docs/StringNe.md)
 - [StringRegExp](docs/StringRegExp.md)
 - [StringUnlike](docs/StringUnlike.md)
 - [StringiEq](docs/StringiEq.md)
 - [StringiLike](docs/StringiLike.md)
 - [StringiNe](docs/StringiNe.md)
 - [StringiUnlike](docs/StringiUnlike.md)
 - [TemplFromProcessType](docs/TemplFromProcessType.md)
 - [TimeTrigger](docs/TimeTrigger.md)
 - [TimeTriggerAttribute](docs/TimeTriggerAttribute.md)
 - [TimedProcessTrigger](docs/TimedProcessTrigger.md)
 - [UdtValue](docs/UdtValue.md)
 - [UnknownSessionException](docs/UnknownSessionException.md)
 - [UpdateInterval](docs/UpdateInterval.md)
 - [UriFilter](docs/UriFilter.md)
 - [UriSelection](docs/UriSelection.md)
 - [UserAttributesFilter](docs/UserAttributesFilter.md)
 - [UserAttributesSelection](docs/UserAttributesSelection.md)
 - [UuidEq](docs/UuidEq.md)
 - [UuidFilter](docs/UuidFilter.md)
 - [UuidNe](docs/UuidNe.md)
 - [Value](docs/Value.md)
 - [ValueAttribute](docs/ValueAttribute.md)
 - [WorklistItem](docs/WorklistItem.md)
 - [WorklistItemStateFilter](docs/WorklistItemStateFilter.md)
 - [WorklistItemStateIn](docs/WorklistItemStateIn.md)
 - [WorklistItemStateNotIn](docs/WorklistItemStateNotIn.md)
 - [WorklistRevision](docs/WorklistRevision.md)
 - [WorklistUpdate](docs/WorklistUpdate.md)
 - [WorklistUpdateConfiguration](docs/WorklistUpdateConfiguration.md)
 - [WorklistUpdateNotification](docs/WorklistUpdateNotification.md)
 - [WorklistsContaining](docs/WorklistsContaining.md)
 - [WrappingException](docs/WrappingException.md)
 - [WrongAgentException](docs/WrongAgentException.md)
 - [WrongRuntimeManagerException](docs/WrongRuntimeManagerException.md)
 - [XPathEvaluationException](docs/XPathEvaluationException.md)

## Documentation For Authorization

 All endpoints do not require authorization.


## Author


